@@ -50,6 +50,149 @@ static GOptionEntry entries[] =
     { NULL }
 };
 
+#if GTK_CHECK_VERSION(2,12,0)
+#define RSTTO_COLOR_PARSE gdk_color_parse
+#define RSTTO_COLOR_TO_STRING gdk_color_to_string
+#else
+gboolean
+rstto_color_parse(const gchar *string, GdkColor *color)
+{
+    gint i;
+    guint16 red = 0;
+    guint16 green = 0;
+    guint16 blue = 0;
+    g_return_val_if_fail(string != NULL, FALSE);
+    /* Check is the string is long enough tp contain #rrrrggggbbbb
+     */
+    if(strlen(string) != 13)
+        return FALSE;
+    if(string[0] != '#')
+        return FALSE;
+
+    /* red */
+    for(i = 1; i < 5; ++i)
+    {
+        if(string[i] >= '0' && string[i] <= '9')
+        {
+            red |= (string[i] ^ 0x30);
+        }
+        else
+        {
+            if(string[i] >= 'a' && string[i] <= 'f')
+            {
+                red |= ((string[i] ^ 0x60)+9);
+            }
+            else
+            {
+                return FALSE;
+            }
+        }
+        if (i < 4)
+            red = red << 4;
+    }
+
+    /* green */
+    for(i = 5; i < 9; ++i)
+    {
+        if(string[i] >= '0' && string[i] <= '9')
+        {
+            green |= (string[i] ^ 0x30);
+        }
+        else
+        {
+            if(string[i] >= 'a' && string[i] <= 'f')
+            {
+                green |= ((string[i] ^ 0x60)+9);
+            }
+            else
+            {
+                return FALSE;
+            }
+        }
+
+        if (i < 8)
+            green = green << 4;
+
+    }
+
+    /* blue */
+    for(i = 9; i < 13; ++i)
+    {
+        if(string[i] >= '0' && string[i] <= '9')
+        {
+            blue |= (string[i] ^ 0x30);
+        }
+        else
+        {
+            if(string[i] >= 'a' && string[i] <= 'f')
+            {
+                blue |= ((string[i] ^ 0x60)+9);
+            }
+            else
+            {
+                return FALSE;
+            }
+        }
+        if (i < 12)
+            blue = blue << 4;
+    }
+
+    color->red = red;
+    color->green = green;
+    color->blue = blue;
+    return TRUE;
+}
+
+gchar *
+rstto_color_to_string(const GdkColor *color)
+{
+    gint i;
+    gchar *color_string = g_new0(gchar, 14);
+
+    color_string[0] = '#';
+
+    for(i = 0; i < 4; ++i)
+    {
+        if(((color->red >> (4*i))&0x000f) < 0xA)
+        {
+           color_string[1+3-i] = (((color->red >> (4*i))&0x000f)|0x0030);
+        }
+        else
+        {
+           color_string[1+3-i] = ((((color->red >> (4*i))&0x000f)|0x0060)-9);
+        }
+    }
+
+    for(i = 0; i < 4; ++i)
+    {
+        if(((color->green >> (4*i))&0x000f) < 0xA)
+        {
+           color_string[5+3-i] = (((color->green >> (4*i))&0x000f)|0x0030);
+        }
+        else
+        {
+           color_string[5+3-i] = ((((color->green >> (4*i))&0x000f)|0x0060)-9);
+        }
+    }
+
+    for(i = 0; i < 4; ++i)
+    {
+        if(((color->blue >> (4*i))&0x000f) < 0xA)
+        {
+           color_string[9+3-i] = (((color->blue >> (4*i))&0x000f)|0x0030);
+        }
+        else
+        {
+           color_string[9+3-i] = ((((color->blue >> (4*i))&0x000f)|0x0060)-9);
+        }
+    }
+
+    return color_string;
+}
+#define RSTTO_COLOR_PARSE(string, color) rstto_color_parse(string, color)
+#define RSTTO_COLOR_TO_STRING(color) rstto_color_to_string(color)
+#endif
+
 int main(int argc, char **argv)
 {
     GdkColor *bg_color = NULL;
@@ -96,11 +239,12 @@ int main(int argc, char **argv)
     gint max_cache = xfce_rc_read_int_entry(xfce_rc, "MaxImagesCacheSize", 1);
     gboolean preload_during_slideshow = xfce_rc_read_bool_entry (xfce_rc, "PreloadDuringSlideShow", FALSE);
     gboolean override_bg_color = xfce_rc_read_bool_entry (xfce_rc, "OverrideBgColor", FALSE);
+
     if (override_bg_color)
     {
         const gchar *color = xfce_rc_read_entry(xfce_rc, "BgColor", "#000000000000");
         bg_color = g_new0(GdkColor, 1);
-        if(!gdk_color_parse(color, bg_color))
+        if(!RSTTO_COLOR_PARSE(color, bg_color))
         {
             g_debug("parse failed");
         }
@@ -194,7 +338,10 @@ int main(int argc, char **argv)
         {
             ThunarVfsPath *path;
             if (g_path_is_absolute(argv[1]))
+            {
                 path = thunar_vfs_path_new(argv[1], NULL);
+                path_dir = g_strdup(argv[1]);
+            }
             else
             {
                 gchar *base_dir = g_get_current_dir();
@@ -269,7 +416,7 @@ int main(int argc, char **argv)
                         const gchar *filename = g_dir_read_name(dir);
                         while (filename)
                         {
-                            gchar *path_name = g_strconcat(argv[1],  "/", filename, NULL);
+                            gchar *path_name = g_strconcat(path_dir,  "/", filename, NULL);
                             ThunarVfsPath *file_path = thunar_vfs_path_new(path_name, NULL);
                             if (file_path)
                             {
@@ -298,110 +445,6 @@ int main(int argc, char **argv)
 
         }
     }
-    /*
-    for (n = 1; n < argc; ++n)
-    {
-        ThunarVfsPath *path;
-        if (g_path_is_absolute(argv[n]))
-            path = thunar_vfs_path_new(argv[n], NULL);
-        else
-        {
-            gchar *base_dir = g_get_current_dir();
-
-            path_dir = g_build_path("/", base_dir, argv[n], NULL);
-            path = thunar_vfs_path_new(path_dir, NULL);
-
-            g_free(base_dir);
-        }
-
-        if (path)
-        {
-
-            ThunarVfsInfo *info = thunar_vfs_info_new_for_path(path, NULL);
-            if(info)
-            {
-                if(strcmp(thunar_vfs_mime_info_get_name(info->mime_info), "inode/directory"))
-                {
-                    ThunarVfsPath *_path = thunar_vfs_path_get_parent(path);
-                    thunar_vfs_path_unref(path);
-                    path = _path;
-
-                    gchar *path_string = thunar_vfs_path_dup_string(path);
-                    
-                    GDir *dir = g_dir_open(path_string, 0, NULL);
-                    const gchar *filename = g_dir_read_name(dir);
-                    while (filename)
-                    {
-                        gchar *path_name = g_strconcat(path_string,  "/", filename, NULL);
-                        ThunarVfsPath *file_path = thunar_vfs_path_new(path_name, NULL);
-                        if (file_path)
-                        {
-                            ThunarVfsInfo *file_info = thunar_vfs_info_new_for_path(file_path, NULL);
-                            gchar *file_media = thunar_vfs_mime_info_get_media(file_info->mime_info);
-                            if(!strcmp(file_media, "image"))
-                            {
-                                RsttoNavigatorEntry *entry = rstto_navigator_entry_new(navigator, file_info);
-                                gint i = rstto_navigator_add (navigator, entry);
-                                if (path_dir == NULL)
-                                {
-                                    if (!strcmp(path_name, argv[n]))
-                                    {
-                                        rstto_navigator_set_file(navigator, i);
-                                    }
-                                }
-                                else
-                                {
-                                    if (!strcmp(path_name, path_dir))
-                                    {
-                                        rstto_navigator_set_file(navigator, i);
-                                    }
-
-                                }
-                            }
-                            g_free(file_media);
-                            thunar_vfs_path_unref(file_path);
-                        }
-                        g_free(path_name);
-                        filename = g_dir_read_name(dir);
-                    }
-                    g_dir_close(dir);
-                    g_free(path_string);
-                }
-                else
-                {
-                    GDir *dir = g_dir_open(argv[n], 0, NULL);
-                    const gchar *filename = g_dir_read_name(dir);
-                    while (filename)
-                    {
-                        gchar *path_name = g_strconcat(argv[n],  "/", filename, NULL);
-                        ThunarVfsPath *file_path = thunar_vfs_path_new(path_name, NULL);
-                        if (file_path)
-                        {
-                            ThunarVfsInfo *file_info = thunar_vfs_info_new_for_path(file_path, NULL);
-                            gchar *file_media = thunar_vfs_mime_info_get_media(file_info->mime_info);
-                            if(!strcmp(file_media, "image"))
-                            {
-                                RsttoNavigatorEntry *entry = rstto_navigator_entry_new(navigator, file_info);
-                                rstto_navigator_add (navigator, entry);
-                            }
-                            g_free(file_media);
-                            thunar_vfs_path_unref(file_path);
-                        }
-                        g_free(path_name);
-                        filename = g_dir_read_name(dir);
-                    }
-                    rstto_navigator_jump_first(navigator);
-                    g_dir_close(dir);
-                }
-                gchar *uri = thunar_vfs_path_dup_uri(info->path);
-                gtk_recent_manager_add_item(recent_manager, uri);
-                g_free(uri);
-            }
-            thunar_vfs_path_unref(path);
-        }
-    }
-*/
-
 
     g_signal_connect(G_OBJECT(window), "destroy", G_CALLBACK(gtk_main_quit), NULL);
     g_signal_connect(G_OBJECT(window), "configure-event", G_CALLBACK(cb_rstto_main_window_configure_event), NULL);
@@ -438,7 +481,7 @@ int main(int argc, char **argv)
     if (bg_color)
     {
         xfce_rc_write_bool_entry(xfce_rc, "OverrideBgColor", TRUE);
-        xfce_rc_write_entry(xfce_rc, "BgColor", gdk_color_to_string(bg_color));
+        xfce_rc_write_entry(xfce_rc, "BgColor", RSTTO_COLOR_TO_STRING(bg_color));
     }
     else
     {
